@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -18,41 +18,43 @@
 #pragma once
 
 #include "color_wheel.hpp"
-#include "src/widgets/capture/capturebutton.h"
+#include "src/widgets/capture/capturetoolbutton.h"
 #include <QGroupBox>
 
 class QVBoxLayout;
 class QHBoxLayout;
-class CaptureButton;
+class CaptureToolButton;
 class ClickableLabel;
 
-class UIcolorEditor : public QGroupBox {
-    Q_OBJECT
+class UIcolorEditor : public QGroupBox
+{
+  Q_OBJECT
 public:
-    explicit UIcolorEditor(QWidget *parent = nullptr);
+  explicit UIcolorEditor(QWidget* parent = nullptr);
 
 public slots:
-    void updateComponents();
+  void updateComponents();
 
 private slots:
-    void updateUIcolor();
-    void updateLocalColor(const QColor);
-    void changeLastButton(CaptureButton *);
+  void updateUIcolor();
+  void updateLocalColor(const QColor);
+  void changeLastButton(CaptureToolButton*);
 
 private:
-    QColor m_uiColor, m_contrastColor;
-    CaptureButton *m_buttonMainColor;
-    ClickableLabel *m_labelMain;
-    CaptureButton *m_buttonContrast;
-    ClickableLabel *m_labelContrast;
-    CaptureButton *m_lastButtonPressed;
-    color_widgets::ColorWheel *m_colorWheel;
+  QColor m_uiColor, m_contrastColor;
+  CaptureToolButton* m_buttonMainColor;
+  ClickableLabel* m_labelMain;
+  CaptureToolButton* m_buttonContrast;
+  ClickableLabel* m_labelContrast;
+  CaptureToolButton* m_lastButtonPressed;
+  color_widgets::ColorWheel* m_colorWheel;
 
-    static const CaptureButton::ButtonType m_buttonIconType = CaptureButton::TYPE_CIRCLE;
+  static const CaptureToolButton::ButtonType m_buttonIconType =
+    CaptureToolButton::TYPE_CIRCLE;
 
-    QHBoxLayout *m_hLayout;
-    QVBoxLayout *m_vLayout;
+  QHBoxLayout* m_hLayout;
+  QVBoxLayout* m_vLayout;
 
-    void initColorWheel();
-    void initButtons();
+  void initColorWheel();
+  void initButtons();
 };
