@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -19,20 +19,23 @@
 
 #include "src/tools/abstractactiontool.h"
 
-class ExitTool : public AbstractActionTool {
-    Q_OBJECT
+class ExitTool : public AbstractActionTool
+{
+  Q_OBJECT
 public:
-    explicit ExitTool(QObject *parent = nullptr);
+  explicit ExitTool(QObject* parent = nullptr);
 
-    bool closeOnButtonPressed() const;
+  bool closeOnButtonPressed() const;
 
-    QIcon icon(const QColor &background, bool inEditor) const override;
-    QString name() const override;
-    static QString nameID();
-    QString description() const override;
+  QIcon icon(const QColor& background, bool inEditor) const override;
+  QString name() const override;
+  QString description() const override;
 
-    CaptureTool* copy(QObject *parent = nullptr) override;
+  CaptureTool* copy(QObject* parent = nullptr) override;
+
+protected:
+  ToolType nameID() const override;
 
 public slots:
-    void pressed(const CaptureContext &context) override;
+  void pressed(const CaptureContext& context) override;
 };
