@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -19,25 +19,27 @@
 
 #include <QString>
 
-class DesktopInfo {
+class DesktopInfo
+{
 public:
-    DesktopInfo();
+  DesktopInfo();
 
-    enum WM {
-        GNOME,
-        KDE,
-        OTHER
-    };
+  enum WM
+  {
+    GNOME,
+    KDE,
+    OTHER
+  };
 
-    bool waylandDectected();
-    WM windowManager();
+  bool waylandDectected();
+  WM windowManager();
 
 private:
-    QString XDG_CURRENT_DESKTOP;
-    QString XDG_SESSION_TYPE;
-    QString WAYLAND_DISPLAY;
-    QString KDE_FULL_SESSION;
-    QString GNOME_DESKTOP_SESSION_ID;
-    QString GDMSESSION;
-    QString DESKTOP_SESSION;
+  QString XDG_CURRENT_DESKTOP;
+  QString XDG_SESSION_TYPE;
+  QString WAYLAND_DISPLAY;
+  QString KDE_FULL_SESSION;
+  QString GNOME_DESKTOP_SESSION_ID;
+  QString GDMSESSION;
+  QString DESKTOP_SESSION;
 };
