@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -21,10 +21,13 @@
 
 namespace PathInfo { // namespace
 
-const QString whiteIconPath();
+const QString
+whiteIconPath();
 
-const QString blackIconPath();
+const QString
+blackIconPath();
 
-QStringList translationsPaths();
+QStringList
+translationsPaths();
 
 } // namespace
