@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -20,13 +20,14 @@
 #include "src/utils/desktopinfo.h"
 #include <QObject>
 
-class ScreenGrabber : public QObject {
-    Q_OBJECT
+class ScreenGrabber : public QObject
+{
+  Q_OBJECT
 public:
-    explicit ScreenGrabber(QObject *parent = nullptr);
-    QPixmap grabEntireDesktop(bool &ok);
-    QPixmap grabScreen(int screenNumber, bool &ok);
+  explicit ScreenGrabber(QObject* parent = nullptr);
+  QPixmap grabEntireDesktop(bool& ok);
+  QPixmap grabScreen(int screenNumber, bool& ok);
 
 private:
-    DesktopInfo m_info;
+  DesktopInfo m_info;
 };
