@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -19,29 +19,30 @@
 
 #include <QWidget>
 
-class ColorPicker : public QWidget {
-    Q_OBJECT
+class ColorPicker : public QWidget
+{
+  Q_OBJECT
 public:
-    explicit ColorPicker(QWidget *parent = nullptr);
+  explicit ColorPicker(QWidget* parent = nullptr);
 
-    QColor drawColor();
+  QColor drawColor();
 
-    void show();
-    void hide();
+  void show();
+  void hide();
 
 signals:
-    void colorSelected(QColor c);
+  void colorSelected(QColor c);
 
 protected:
-    void paintEvent(QPaintEvent *);
-    void mouseMoveEvent(QMouseEvent *);
+  void paintEvent(QPaintEvent*);
+  void mouseMoveEvent(QMouseEvent*);
 
-    QVector<QRect> handleMask() const;
+  QVector<QRect> handleMask() const;
 
 private:
-    int m_colorAreaSize;
-    QVector<QRect> m_colorAreaList;
-    QVector<QColor> m_colorList;
+  int m_colorAreaSize;
+  QVector<QRect> m_colorAreaList;
+  QVector<QColor> m_colorList;
 
-    QColor m_uiColor, m_drawColor;
+  QColor m_uiColor, m_drawColor;
 };
