@@ -1,4 +1,4 @@
-// Copyright(c) 2017-2018 Alejandro Sirgo Rica & Contributors
+// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
 //
 // This file is part of Flameshot.
 //
@@ -19,31 +19,32 @@
 
 #include <QWidget>
 
-class LoadSpinner : public QWidget {
-    Q_OBJECT
+class LoadSpinner : public QWidget
+{
+  Q_OBJECT
 public:
-    explicit LoadSpinner(QWidget *parent = nullptr);
+  explicit LoadSpinner(QWidget* parent = nullptr);
 
-    void setColor(const QColor &c);
-    void setWidth(int w);
-    void setHeight(int h);
-    void start();
-    void stop();
+  void setColor(const QColor& c);
+  void setWidth(int w);
+  void setHeight(int h);
+  void start();
+  void stop();
 
 protected:
-    void paintEvent(QPaintEvent *);
+  void paintEvent(QPaintEvent*);
 
 private slots:
-    void rotate();
+  void rotate();
 
 private:
-    QColor m_color;
-    QTimer *m_timer;
+  QColor m_color;
+  QTimer* m_timer;
 
-    int m_startAngle = 0;
-    int m_span =180;
-    bool m_growing;
+  int m_startAngle = 0;
+  int m_span = 180;
+  bool m_growing;
 
-    QRect  m_frame;
-    void updateFrame();
+  QRect m_frame;
+  void updateFrame();
 };
